arrc.callbacks.visualizer\_callback
===================================

.. automodule:: arrc.callbacks.visualizer_callback

   
   .. rubric:: Classes

   .. autosummary::
   
      AbstractVisualizerCallback
   